#!/bin/bash

CMD=`realpath $0`
COMMON_DIR=`dirname $CMD`
TMP_WORK_DIR="$COMMON_DIR/tmp"

if (unzip -h && zip -h && lzip -h && find --help) &>/dev/null ; then
	# all needed tools are installed
	:
else
	echo "ERR: Missing required tools, aborting"
	echo "Install: unzip, zip, lzip, find"
	exit 1
fi

OZIP=$(ls -1tr open_gapps*.zip 2>/dev/null|tail -1)
if [ -z "$OZIP" ]; then
	echo "ERR: open_gapps*.zip not found in current directory, aborting."
	exit 1
fi
# cut trailing .zip
ODIR=${OZIP/.zip}
OARCH=$(echo $OZIP|cut -f2 -d-)

if [ \! -d "$ODIR" ]; then
	echo "INFO: Extracting $OZIP"
	unzip -q "$OZIP" -d "$ODIR"
else
	echo "INFO: Using already extracted: $ODIR"
fi
echo

mkdir -p $TMP_WORK_DIR/Core

for f in "$ODIR"/Core/*.tar.lz; do
	lzip -c -d "$f" | tar -x -C "$TMP_WORK_DIR/Core"
done

mkdir -p $TMP_WORK_DIR/GApps
for f in "$ODIR"/GApps/*.tar.lz; do
	lzip -c -d "$f" | tar -x -C "$TMP_WORK_DIR/GApps"
done

adb root
sleep 5
adb remount
sleep 3

adb shell rm -rf /system/priv-app/PackageInstaller
adb shell rm -rf /product/priv-app/OneTimeInitializer
adb shell rm -rf /system_ext/priv-app/Provision
adb push google-hiddenapi-package-whitelist.xml /product/etc/sysconfig/

adb push tmp/Core/googleonetimeinitializer-all/nodpi/priv-app/GoogleOneTimeInitializer/GoogleOneTimeInitializer.apk /product/priv-app/
adb push tmp/Core/googlebackuptransport-all/nodpi/priv-app/GoogleBackupTransport/GoogleBackupTransport.apk /product/priv-app/
adb push tmp/Core/gmscore-arm64/nodpi/priv-app/PrebuiltGmsCore/PrebuiltGmsCore.apk /product/priv-app/
adb push tmp/Core/vending-common/common/product/overlay/PlayStoreOverlay.apk /product/overlay/
adb push tmp/Core/backuprestore-all/nodpi/priv-app/GoogleRestore/GoogleRestore.apk /product/priv-app/
adb push tmp/Core/carriersetup-all/nodpi/priv-app/CarrierSetup/CarrierSetup.apk /product/priv-app/
adb push tmp/Core/setupwizardtablet-arm64/nodpi/priv-app/SetupWizard/SetupWizard.apk /product/priv-app/
adb push tmp/Core/gsfcore-all/nodpi/priv-app/GoogleServicesFramework/GoogleServicesFramework.apk /product/priv-app/
adb push tmp/Core/extservicesgoogle-all/nodpi/priv-app/GoogleExtServices/GoogleExtServices.apk /product/priv-app/
adb push tmp/Core/googlecontactssync-all/nodpi/app/GoogleContactsSyncAdapter/GoogleContactsSyncAdapter.apk /product/app/
adb push tmp/Core/datatransfertool-all/nodpi/priv-app/AndroidMigratePrebuilt/AndroidMigratePrebuilt.apk /product/priv-app/
adb push tmp/Core/configupdater-all/nodpi/priv-app/ConfigUpdater/ConfigUpdater.apk /product/priv-app/
adb push tmp/Core/extsharedgoogle-all/nodpi/app/GoogleExtShared/GoogleExtShared.apk /product/app/
adb push tmp/Core/vending-arm64/nodpi/priv-app/Phonesky/Phonesky.apk /product/priv-app/
adb push tmp/Core/googlepartnersetup-all/nodpi/priv-app/GooglePartnerSetup/GooglePartnerSetup.apk /product/priv-app/
adb push tmp/Core/setupwizarddefault-arm64/nodpi/priv-app/SetupWizard/SetupWizard.apk /product/priv-app/
adb push tmp/Core/googlefeedback-all/nodpi/priv-app/GoogleFeedback/GoogleFeedback.apk /product/priv-app/

adb push tmp/GApps/calsync-all/nodpi/app/GoogleCalendarSyncAdapter/GoogleCalendarSyncAdapter.apk /product/app/
adb push tmp/GApps/markup-all/nodpi/app/MarkupGoogle/MarkupGoogle.apk /product/app/
adb push tmp/GApps/batteryusage-arm64/nodpi/priv-app/Turbo/Turbo.apk /product/priv-app/
adb push tmp/GApps/googletts-arm64/nodpi/app/GoogleTTS/GoogleTTS.apk /product/app/
adb push tmp/GApps/wellbeing-common/common/product/overlay/WellbeingOverlay.apk /product/overlay/
adb push tmp/GApps/soundpicker-all/nodpi/app/SoundPickerPrebuilt/SoundPickerPrebuilt.apk /product/app/
adb push tmp/GApps/gearheadstub-all/nodpi/priv-app/AndroidAutoPrebuiltStub/AndroidAutoPrebuiltStub.apk /product/priv-app/
adb push tmp/GApps/packageinstallergoogle-all/nodpi/priv-app/GooglePackageInstaller/GooglePackageInstaller.apk /product/priv-app/
adb push tmp/GApps/search-arm64/nodpi/priv-app/Velvet/Velvet.apk /product/priv-app/
adb push tmp/GApps/wellbeing-all/nodpi/priv-app/WellbeingPrebuilt/WellbeingPrebuilt.apk /product/priv-app/

adb reboot

rm -rf $TMP_WORK_DIR
rm -rf $ODIR
